# Cowpox
Deploy Android apps written in Python
## Quick start
* To simply use Cowpox you shouldn't need to build anything as an image is available on [Docker Hub](https://hub.docker.com/r/combatopera/cowpox)
* See [android-hello-world](https://github.com/combatopera/android-hello-world/blob/trunk/README.md) for an example project that Cowpox can turn into an Android APK
## Licensing
* Cowpox as a whole is provided under the terms of the GPL, see [COPYING](COPYING)
* The [MIT](MIT) tree is additionally/instead provided under [LICENSE.kivy](LICENSE.kivy)
  * This covers all Cowpox code that can end up in your APK
* Cowpox is in essence a heavily refactored [Buildozer](https://github.com/kivy/buildozer) and [python-for-android](https://github.com/kivy/python-for-android), without which it would not exist
## Contact
* DMs open [@Cowpox2020](https://twitter.com/Cowpox2020)
